from typing import AsyncIterator, Dict

from aiobotocore.paginate import AioPaginator


class ListAccountRoles(AioPaginator):
    async def paginate(self, accessToken: str, accountId: str, PaginationConfig: Dict = None) -> AsyncIterator[Dict]:
        """
        Creates an iterator that will paginate through responses from :py:meth:`SSO.Client.list_account_roles`.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/sso-2019-06-10/ListAccountRoles>`_
        
        **Request Syntax**
        ::
          response_iterator = paginator.paginate(
              accessToken='string',
              accountId='string',
              PaginationConfig={
                  'MaxItems': 123,
                  'PageSize': 123,
                  'StartingToken': 'string'
              }
          )
        
        **Response Syntax**
        ::
            {
                'roleList': [
                    {
                        'roleName': 'string',
                        'accountId': 'string'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **roleList** *(list) --* 
              A paginated response with the list of roles and the next token if more results are available.
              - *(dict) --* 
                Provides information about the role that is assigned to the user.
                - **roleName** *(string) --* 
                  The friendly name of the role that is assigned to the user.
                - **accountId** *(string) --* 
                  The identifier of the AWS account assigned to the user.
            - **NextToken** *(string) --* 
              A token to resume pagination.
        :type accessToken: string
        :param accessToken: **[REQUIRED]**
          The token issued by the ``CreateToken`` API call. For more information, see `CreateToken <https://docs.aws.amazon.com/singlesignon/latest/OIDCAPIReference/API_CreateToken.html>`__ in the *AWS SSO OIDC API Reference Guide* .
        :type accountId: string
        :param accountId: **[REQUIRED]**
          The identifier for the AWS account that is assigned to the user.
        :type PaginationConfig: dict
        :param PaginationConfig:
          A dictionary that provides parameters to control pagination.
          - **MaxItems** *(integer) --*
            The total number of items to return. If the total number of items available is more than the value specified in max-items then a ``NextToken`` will be provided in the output that you can use to resume pagination.
          - **PageSize** *(integer) --*
            The size of each page.
          - **StartingToken** *(string) --*
            A token to specify where to start paginating. This is the ``NextToken`` from a previous response.
        :rtype: dict
        :returns:
        """


class ListAccounts(AioPaginator):
    async def paginate(self, accessToken: str, PaginationConfig: Dict = None) -> AsyncIterator[Dict]:
        """
        Creates an iterator that will paginate through responses from :py:meth:`SSO.Client.list_accounts`.
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/sso-2019-06-10/ListAccounts>`_
        
        **Request Syntax**
        ::
          response_iterator = paginator.paginate(
              accessToken='string',
              PaginationConfig={
                  'MaxItems': 123,
                  'PageSize': 123,
                  'StartingToken': 'string'
              }
          )
        
        **Response Syntax**
        ::
            {
                'accountList': [
                    {
                        'accountId': 'string',
                        'accountName': 'string',
                        'emailAddress': 'string'
                    },
                ],
                'NextToken': 'string'
            }
        
        **Response Structure**
          - *(dict) --* 
            - **accountList** *(list) --* 
              A paginated response with the list of account information and the next token if more results are available.
              - *(dict) --* 
                Provides information about your AWS account.
                - **accountId** *(string) --* 
                  The identifier of the AWS account that is assigned to the user.
                - **accountName** *(string) --* 
                  The display name of the AWS account that is assigned to the user.
                - **emailAddress** *(string) --* 
                  The email address of the AWS account that is assigned to the user.
            - **NextToken** *(string) --* 
              A token to resume pagination.
        :type accessToken: string
        :param accessToken: **[REQUIRED]**
          The token issued by the ``CreateToken`` API call. For more information, see `CreateToken <https://docs.aws.amazon.com/singlesignon/latest/OIDCAPIReference/API_CreateToken.html>`__ in the *AWS SSO OIDC API Reference Guide* .
        :type PaginationConfig: dict
        :param PaginationConfig:
          A dictionary that provides parameters to control pagination.
          - **MaxItems** *(integer) --*
            The total number of items to return. If the total number of items available is more than the value specified in max-items then a ``NextToken`` will be provided in the output that you can use to resume pagination.
          - **PageSize** *(integer) --*
            The size of each page.
          - **StartingToken** *(string) --*
            A token to specify where to start paginating. This is the ``NextToken`` from a previous response.
        :rtype: dict
        :returns:
        """
